==> pgxRpi_1.0.3.tgz: pgxRpi/doc/Introduction_2_loadvariants.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)

## -----------------------------------------------------------------------------
cnv_matrix <- pgxLoader(type="variant", output="pgxmatrix", filters = "NCIT:C2948")

## -----------------------------------------------------------------------------
print(dim(cnv_matrix))
cnv_matrix[c(1:3), c(1:5,6213:6215)]

## -----------------------------------------------------------------------------
cnv_covergae <- pgxLoader(type="variant", output="coverage", filters = "NCIT:C2948")

## -----------------------------------------------------------------------------
names(cnv_covergae)

## -----------------------------------------------------------------------------
head(cnv_covergae$chrom_arm_coverage)[,c(1:4, 49:52)]

## -----------------------------------------------------------------------------
head(cnv_covergae$whole_genome_coverage)

## -----------------------------------------------------------------------------
cnv_covergae_2 <- pgxLoader(type="variant", output="coverage", filters = "NCIT:C2948",
                            codematches = TRUE)

print(dim(cnv_covergae$chrom_arm_coverage))
print(dim(cnv_covergae_2$chrom_arm_coverage))

## -----------------------------------------------------------------------------
cnv_matrix_2 <- pgxLoader(type="variant", output="pgxmatrix", 
                          filters = "NCIT:C2948",
                          skip = 0, limit=10)
# the dimention of subset 
print(dim(cnv_matrix_2))
# the dimention of original set
print(dim(cnv_matrix))

## -----------------------------------------------------------------------------
cnv_ind_matrix <- pgxLoader(type="variant", output="pgxmatrix", 
                          biosample_id = "pgxbs-kftva604",
                          individual_id = "pgxind-kftx5g4t")

cnv_ind_cov <- pgxLoader(type="variant", output="coverage", 
                          biosample_id = "pgxbs-kftva604",
                          individual_id = "pgxind-kftx5g4t")

## -----------------------------------------------------------------------------
biosamples <- pgxLoader(type="biosample", filters = "PMID:20229506", limit=2)

biosample_id <- biosamples$biosample_id

## -----------------------------------------------------------------------------
variant_1 <- pgxLoader(type="variant", biosample_id = biosample_id)
head(variant_1)

## -----------------------------------------------------------------------------
variant_2 <- pgxLoader(type="variant", biosample_id = biosample_id,output = "pgxseg")
head(variant_2)

## -----------------------------------------------------------------------------
variant_3 <- pgxLoader(type="variant", biosample_id = biosample_id,output = "seg")
head(variant_3)

## ----eval=FALSE---------------------------------------------------------------
#  pgxLoader(type="variant", output="pgxseg", biosample_id=biosample_id, save_file=TRUE,
#            filename="~/Downloads/variants.pgxseg")

## ----eval=FALSE---------------------------------------------------------------
#  pgxLoader(type="variant", output="seg", biosample_id=biosample_id, save_file=TRUE,
#            filename="~/Downloads/variants.seg")

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()

==> pgxRpi_1.0.5.tgz: pgxRpi/doc/Introduction_2_loadvariants.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)

## -----------------------------------------------------------------------------
cnv_matrix <- pgxLoader(type="variant", output="pgxmatrix", filters = "NCIT:C2948")

## -----------------------------------------------------------------------------
print(dim(cnv_matrix))
cnv_matrix[c(1:3), c(1:5,6213:6215)]

## -----------------------------------------------------------------------------
cnv_coverage <- pgxLoader(type="variant", output="coverage", filters = "NCIT:C2948")

## -----------------------------------------------------------------------------
names(cnv_coverage)

## -----------------------------------------------------------------------------
head(cnv_coverage$chrom_arm_coverage)[,c(1:4, 49:52)]

## -----------------------------------------------------------------------------
head(cnv_coverage$whole_genome_coverage)

## -----------------------------------------------------------------------------
cnv_coverage_2 <- pgxLoader(type="variant", output="coverage", filters = "NCIT:C2948",
                            codematches = TRUE)

print(dim(cnv_coverage$chrom_arm_coverage))
print(dim(cnv_coverage_2$chrom_arm_coverage))

## -----------------------------------------------------------------------------
cnv_matrix_2 <- pgxLoader(type="variant", output="pgxmatrix", 
                          filters = "NCIT:C2948",
                          skip = 0, limit=10)
# the dimention of subset 
print(dim(cnv_matrix_2))
# the dimention of original set
print(dim(cnv_matrix))

## -----------------------------------------------------------------------------
cnv_ind_matrix <- pgxLoader(type="variant", output="pgxmatrix", 
                          biosample_id = "pgxbs-kftva604",
                          individual_id = "pgxind-kftx5g4t")

cnv_ind_cov <- pgxLoader(type="variant", output="coverage", 
                          biosample_id = "pgxbs-kftva604",
                          individual_id = "pgxind-kftx5g4t")

## -----------------------------------------------------------------------------
biosamples <- pgxLoader(type="biosample", filters = "PMID:20229506", limit=2)

biosample_id <- biosamples$biosample_id

## -----------------------------------------------------------------------------
variant_1 <- pgxLoader(type="variant", biosample_id = biosample_id)
head(variant_1)

## -----------------------------------------------------------------------------
variant_2 <- pgxLoader(type="variant", biosample_id = biosample_id,output = "pgxseg")
head(variant_2)

## -----------------------------------------------------------------------------
variant_3 <- pgxLoader(type="variant", biosample_id = biosample_id,output = "seg")
head(variant_3)

## ----eval=FALSE---------------------------------------------------------------
#  pgxLoader(type="variant", output="pgxseg", biosample_id=biosample_id, save_file=TRUE,
#            filename="~/Downloads/variants.pgxseg")

## ----eval=FALSE---------------------------------------------------------------
#  pgxLoader(type="variant", output="seg", biosample_id=biosample_id, save_file=TRUE,
#            filename="~/Downloads/variants.seg")

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()
